@@ -25,7 +25,7 @@
 #ifndef EXTERN_H_
 #define EXTERN_H_
 
-#define EXTERN_H_CVSID "$Id: extern.h,v 1.41 2006/04/12 14:54:28 ballen4705 Exp $\n"
+#define EXTERN_H_CVSID "$Id: extern.h,v 1.47 2006/09/15 08:03:52 sxzzsf Exp $\n"
 
 // Possible values for fixfirmwarebug.  If use has NOT specified -F at
 // all, then value is 0.
@@ -50,6 +50,8 @@ typedef struct smartmonctrl_s {
   // turn off scan after selective self-test, 2: turn on scan after
   // selective self-test.
   unsigned char scanafterselect;
+  // skip check, if disk in idle or standby mode
+  unsigned char powermode;
   unsigned char driveinfo;
   unsigned char checksmart;
   unsigned char smartvendorattrib;
@@ -58,6 +60,7 @@ typedef struct smartmonctrl_s {
   unsigned char smartselftestlog;
   unsigned char selectivetestlog;
   unsigned char smarterrorlog;
+  unsigned char smartbackgroundlog;
   unsigned char smartdisable;
   unsigned char smartenable; 
   unsigned char smartstatus;
@@ -84,10 +87,15 @@ typedef struct smartmonctrl_s {
   unsigned char reportataioctl;
   unsigned char reportscsiioctl;
   unsigned char fixfirmwarebug;
+  unsigned char satpassthrulen;
+  // Controller type (device type) has been specified explicitly
+  unsigned char controller_explicit;
   // 3Ware controller type, but also extensible to other contoller types
   unsigned char controller_type;
   // For 3Ware controllers, nonzero value is 1 plus the disk number
   unsigned char controller_port;
+  // combined controller/channle/pmport for highpoint rocketraid controller
+  unsigned char hpt_data[3];
   unsigned char ignorepresets;
   unsigned char showpresets;
   // The i'th entry in this array will modify the printed meaning of
